import { Role, TaskMemberStatus, TaskStatus } from '@/utils/enums';
import { checkPermi, checkRole } from '@/utils/permission';
import { mapGetters } from 'vuex';
export const $task = {
  computed: {
    ...mapGetters(['userId']),
    // 是否可以提交
    canSubmit() {
      return (row) => {
        return checkPermi(['bst:task:submit']) 
          && TaskStatus.canSubmit().includes(row.status) 
          && row.memberList != null
          && row.memberList.some(item => item.userId === this.userId);      
      }
    },
    // 是否可以取消
    canCancel() {
      return (row) => {
        return checkPermi(['bst:task:cancel']) 
          && TaskStatus.canCancel().includes(row.status)
          && (checkRole([Role.SYS_ADMIN, Role.ADMIN]) || this.isCreator(row));
      }
    },
    // 是否可以完成
    canPass() {
      return (row) => {
        return checkPermi(['bst:task:pass']) 
          && TaskStatus.canPass().includes(row.status);
      }
    },
    // 是否可以修改
    canEdit() {
      return (row) => {
        return checkPermi(['bst:task:edit']) 
          && (checkRole([Role.SYS_ADMIN, Role.ADMIN]) || this.isCreator(row));
      }
    },
    // 是否可以删除
    canDel() {
      return (row) => {
        return checkPermi(['bst:task:remove']) 
          && (checkRole([Role.SYS_ADMIN, Role.ADMIN]) || this.isCreator(row));
      }
    },
    // 是否是创建者
    isCreator() {
      return (row) => {
        return row.createId === this.userId;
      }
    },
    // 是否可以接取
    canReceive() {
      return (row) => {
        if (row.memberList == null) {
          return false;
        }
        // 当前成员信息
        let member = row.memberList.find(item => item.userId === this.userId);
        if (member == null) {
          return false;
        }
        return checkPermi(['bst:task:receive']) && TaskMemberStatus.canReceive().includes(member.status);
      }

    }
  }
}